<?php
if (!defined('ABSPATH')) exit;
?>

<div class="wrap">
    <h1><?php _e('RSS文章列表', 'jefrssfriend'); ?></h1>
    
    <!-- 刷新控件容器 -->
    <div class="refresh-controls">
        <!-- 刷新按钮 -->
        <button id="refresh-all-feeds" class="button button-primary">
            <?php _e('刷新全部', 'jefrssfriend'); ?>
        </button>
        
        <!-- 进度条容器 -->
        <div class="refresh-progress" style="display: none;">
            <div class="progress-bar"></div>
            <div class="progress-text"></div>
            <div class="refresh-errors"></div>
        </div>
    </div>
    
    <?php wp_nonce_field('jefrssfriend-admin', '_wpnonce', false); ?>
    
    <!-- 添加移动端筛选切换按钮 -->
    <button type="button" class="filter-toggle button" style="display: none;">
        <?php _e('显示筛选选项', 'jefrssfriend'); ?>
    </button>
    
    <!-- 筛选表单 -->
    <form method="get" class="jefrss-filter-form">
        <input type="hidden" name="page" value="jefrssfriend">
        
        <div class="tablenav top">
            <div class="alignleft actions">
                <select name="site_id">
                    <option value=""><?php _e('所有站点', 'jefrssfriend'); ?></option>
                    <?php foreach ($sites as $site): ?>
                    <option value="<?php echo $site->id; ?>" <?php selected(isset($_GET['site_id']) ? $_GET['site_id'] : '', $site->id); ?>>
                        <?php echo esc_html($site->title); ?>
                    </option>
                    <?php endforeach; ?>
                </select>
                
                <select name="group_id">
                    <option value=""><?php _e('所有分组', 'jefrssfriend'); ?></option>
                    <?php foreach ($groups as $group): ?>
                    <option value="<?php echo $group->id; ?>" <?php selected(isset($_GET['group_id']) ? $_GET['group_id'] : '', $group->id); ?>>
                        <?php echo esc_html($group->name); ?>
                    </option>
                    <?php endforeach; ?>
                </select>
                
                <input type="submit" class="button" value="<?php _e('筛选', 'jefrssfriend'); ?>">
            </div>
            
            <div class="alignright">
                <p class="search-box">
                    <label class="screen-reader-text" for="article-search"><?php _e('搜索文章:', 'jefrssfriend'); ?></label>
                    <input type="search" id="article-search" name="s" value="<?php echo isset($_GET['s']) ? esc_attr($_GET['s']) : ''; ?>">
                    <input type="submit" class="button" value="<?php _e('搜索', 'jefrssfriend'); ?>">
                </p>
            </div>
        </div>
    </form>
    
    <?php
    $options = get_option('jefrssfriend_options');
    $excerpt_length = isset($options['excerpt_length']) ? intval($options['excerpt_length']) : 100;
    ?>
    
    <!-- 文章列表 -->
    <?php if ($articles): ?>
    <div class="jefrss-articles-list">
        <?php foreach ($articles as $article): ?>
        <div class="article-item">
            <div class="article-header">
                <span class="site-title"><?php echo esc_html($article->site_title); ?></span>
            </div>
            <div class="article-content">
                <?php 
                // 提取文章中的第一张图片
                $first_image = '';
                if (preg_match('/<img.+?src=[\'"]([^\'"]+)[\'"].*?>/i', $article->content, $matches)) {
                    $first_image = $matches[1];
                }
                ?>
                <div class="article-layout <?php echo $first_image ? 'has-image' : 'no-image'; ?>">
                    <?php if ($first_image): ?>
                    <div class="article-image">
                        <img src="<?php echo esc_url($first_image); ?>" 
                             alt=""
                             onerror="this.onerror=null; this.parentElement.style.display='none'; this.closest('.article-layout').classList.add('no-image');">
                    </div>
                    <?php endif; ?>
                    <div class="article-text">
                        <h3 class="article-title">
                            <a href="<?php echo esc_url($article->link); ?>" target="_blank">
                                <?php echo esc_html($article->title); ?>
                            </a>
                        </h3>
                        <div class="article-meta">
                            <img src="<?php echo esc_url('https://unavatar.io/' . parse_url($article->site_url, PHP_URL_HOST)); ?>" 
                                 class="site-icon-small" 
                                 alt="<?php echo esc_attr($article->site_title); ?>">
                            <span class="pub-date"><?php echo human_time_diff(strtotime($article->pub_date)) . __('前', 'jefrssfriend'); ?></span>
                        </div>
                        <div class="article-excerpt">
                            <?php 
                            // 获取设置中的摘要长度
                            $options = get_option('jefrssfriend_options');
                            $excerpt_length = isset($options['excerpt_length']) ? intval($options['excerpt_length']) : 200;
                            
                            // 应该优先使用 description 字段
                            $excerpt = !empty($article->description) ? $article->description : wp_strip_all_tags($article->content);
                            
                            // 截取指定长度
                            if (mb_strlen($excerpt) > $excerpt_length) {
                                $excerpt = mb_substr($excerpt, 0, $excerpt_length) . '...';
                            }
                            
                            echo esc_html($excerpt);
                            ?>
                        </div>
                        <div class="article-actions">
                            <span class="action-expand" title="<?php _e('展开阅读', 'jefrssfriend'); ?>">
                                <a href="<?php echo add_query_arg(array(
                                'page' => 'jefrssfriend-reader',
                                'id' => $article->id
                                ), admin_url('admin.php')); ?>">
                                <svg viewBox="0 0 24 24" width="16" height="16">
                                    <path d="M4 4h16v16H4V4zm2 2v12h12V6H6zm3 5h6v2H9v-2z"/>
                                </svg>
                                <?php _e('展开', 'jefrssfriend'); ?>
                                </a>
                            </span>
                            <span class="action-link" title="<?php _e('查看原文', 'jefrssfriend'); ?>">
                                <a href="<?php echo esc_url($article->link); ?>" target="_blank">
                                <svg viewBox="0 0 24 24" width="16" height="16">
                                    <path d="M19 19H5V5h7V3H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2v-7h-2v7zM14 3v2h3.59l-9.83 9.83 1.41 1.41L19 6.41V10h2V3h-7z"></path>
                                </svg>
                                <?php _e('原文', 'jefrssfriend'); ?>
                                </a>
                            </span>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php endforeach; ?>
    </div>
    
    <?php
    // 分页导航
    $page_links = paginate_links(array(
        'base' => add_query_arg('paged', '%#%'),
        'format' => '',
        'prev_text' => __('&laquo;'),
        'next_text' => __('&raquo;'),
        'total' => $total_pages,
        'current' => $current_page,
        'type' => 'list'
    ));
    
    if ($page_links) {
        echo '<div class="tablenav"><div class="tablenav-pages">';
        echo '<span class="displaying-num">' . sprintf(
            _n('%s 篇文章', '%s 篇文章', $total_items),
            number_format_i18n($total_items)
        ) . '</span>';
        echo $page_links;
        echo '</div></div>';
    }
    ?>
    
    <?php else: ?>
    <p><?php _e('暂无文章。', 'jefrssfriend'); ?></p>
    <?php endif; ?>
</div> 