<?php
if (!defined('ABSPATH')) exit;

/**
 * 移动端阅读视图类
 */
class JefRSSFriend_Mobile_Reader_View {
    protected $articles;
    
    public function __construct() {
        $this->init();
    }
    
    protected function init() {
        // 验证用户权限
        if (!current_user_can('read')) {
            wp_die(__('您没有足够的权限访问此页面', 'jefrssfriend'));
        }
        
        try {
            global $wpdb;
            $this->articles = $wpdb->get_results($wpdb->prepare("
                SELECT a.*, s.title as site_title, s.site_url 
                FROM {$wpdb->prefix}jefrss_articles a
                LEFT JOIN {$wpdb->prefix}jefrss_sites s ON a.site_id = s.id
                WHERE s.status = 'active'
                ORDER BY a.pub_date DESC 
                LIMIT %d
            ", 50));
        } catch (Exception $e) {
            error_log('Mobile Reader Error: ' . $e->getMessage());
            $this->articles = array();
        }
    }

    public function render() {
        ?>
        <script src="https://cdn.jsdelivr.net/npm/darkmode-js@1.5.7/lib/darkmode-js.min.js"></script>
        
        <meta name="color-scheme" content="light dark">
        <meta name="theme-color" content="#ffffff" media="(prefers-color-scheme: light)">
        <meta name="theme-color" content="#242424" media="(prefers-color-scheme: dark)">
        
        <div class="mobile-reader">
            <div class="loading-indicator"></div>
            <div class="reading-progress"></div>
            
            <div class="mobile-view">
                <div class="mobile-articles">
                    <div class="list-header">
                        <h2><?php _e('最新文章', 'jefrssfriend'); ?></h2>
                        <button class="toggle-dark-mode" title="切换夜间模式">
                            <svg viewBox="0 0 24 24" width="18" height="18">
                                <path d="M12 3a9 9 0 1 0 9 9c0-.46-.04-.92-.1-1.36a5.389 5.389 0 0 1-4.4 2.26 5.403 5.403 0 0 1-3.14-9.8c-.44-.06-.9-.1-1.36-.1z"></path>
                            </svg>
                        </button>
                    </div>
                    <div class="list-content">
                        <?php if (empty($this->articles)): ?>
                            <div class="no-articles">
                                <p><?php _e('暂无文章', 'jefrssfriend'); ?></p>
                            </div>
                        <?php else: ?>
                            <?php foreach ($this->articles as $article): ?>
                                <div class="article-item" data-id="<?php echo esc_attr($article->id); ?>">
                                    <img src="<?php echo esc_url($this->get_site_icon($article)); ?>" 
                                         class="site-icon" 
                                         alt="<?php echo esc_attr($article->site_title); ?>"
                                         loading="lazy">
                                    <h3 class="article-title"><?php echo esc_html($article->title); ?></h3>
                                    <div class="article-meta">
                                        <span class="site-title"><?php echo esc_html($article->site_title); ?></span>
                                        <time><?php echo human_time_diff(strtotime($article->pub_date)) . __('前', 'jefrssfriend'); ?></time>
                                    </div>
                                    <div class="article-desc">
                                        <?php echo wp_trim_words(wp_strip_all_tags($article->description), 55); ?>
                                    </div>
                                </div>
                                <div id="article-<?php echo esc_attr($article->id); ?>" class="mobile-article-content">
                                    <div class="article-header">
                                        <h1>
                                            <a href="<?php echo esc_url($article->link); ?>" target="_blank">
                                                <?php echo esc_html($article->title); ?>
                                            </a>
                                        </h1>
                                        <div class="article-meta">
                                            <div class="site-info">
                                                <span class="site-title"><?php echo esc_html($article->site_title); ?></span>
                                                <time><?php echo human_time_diff(strtotime($article->pub_date)) . __('前', 'jefrssfriend'); ?></time>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="article-content">
                                        <?php echo wp_kses_post($article->content); ?>
                                    </div>
                                    <div class="article-footer">
                                        <a href="<?php echo esc_url($article->link); ?>" class="original-link" target="_blank">
                                            <?php _e('访问原文', 'jefrssfriend'); ?>
                                        </a>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
            
            <button class="back-to-top" title="<?php _e('返回顶部', 'jefrssfriend'); ?>">
                <svg viewBox="0 0 24 24" width="24" height="24">
                    <path d="M12 4l-8 8h6v8h4v-8h6z"/>
                </svg>
            </button>
        </div>
        <?php
    }
    
    protected function get_site_icon($article) {
        $site_url = parse_url($article->site_url, PHP_URL_HOST) ?: $article->site_url;
        return 'https://unavatar.io/' . esc_attr($site_url) . '?size=32';
    }
} 