<?php
if (!defined('ABSPATH')) exit;

class JefRSSFriend_Lite_Admin {
    private $settings;
    
    public function __construct() {
        $this->settings = new JefRSSFriend_Lite_Settings();
        
        // 添加菜单
        add_action('admin_menu', array($this, 'add_admin_menu'));
        
        // 添加表单处理
        add_action('admin_post_add_rss_site', array($this, 'handle_add_site'));
        add_action('admin_post_add_rss_group', array($this, 'handle_add_group'));
        add_action('admin_post_import_rss_opml', array($this, 'handle_import_opml'));
        add_action('admin_post_export_rss_opml', array($this, 'handle_export_opml'));
        
        // 注册AJAX处理
        add_action('wp_ajax_jefrssfriend_refresh_feeds', array($this, 'ajax_refresh_feeds'));
        add_action('wp_ajax_jefrssfriend_delete_site', array($this, 'ajax_delete_site'));
        add_action('wp_ajax_jefrssfriend_get_site', array($this, 'ajax_get_site'));
        
        // 添加定时任务钩子
        add_action('jefrssfriend_fetch_feeds', array($this, 'fetch_all_feeds'));
        add_action('jefrssfriend_cron_refresh', array($this, 'handle_cron_refresh'));
        
        // 加载管理界面资源
        add_action('admin_enqueue_scripts', array($this, 'enqueue_admin_assets'));
        
        // 添加新的AJAX处理
        add_action('wp_ajax_jefrssfriend_add_site', array($this, 'ajax_add_site'));
        add_action('wp_ajax_jefrssfriend_delete_site', array($this, 'ajax_delete_site'));
        add_action('wp_ajax_jefrssfriend_add_group', array($this, 'ajax_add_group'));
        add_action('wp_ajax_jefrssfriend_delete_group', array($this, 'ajax_delete_group'));
        
        // 添加AJAX处理
        add_action('wp_ajax_jefrssfriend_refresh_json', array($this, 'ajax_refresh_json'));
        add_action('wp_ajax_jefrssfriend_activate_all_sites', array($this, 'ajax_activate_all_sites'));
        
        // 确保正确注册 AJAX 处理
        add_action('wp_ajax_jefrssfriend_get_article', array($this, 'ajax_get_article'));
        
        // 添加刷新单个站点的 AJAX 处理
        add_action('wp_ajax_jefrssfriend_refresh_single_site', array($this, 'ajax_refresh_single_site'));
    }
    
    public function add_admin_menu() {
        // 主菜单
        add_menu_page(
            __('订阅', 'jefrssfriend'),
            __('订阅', 'jefrssfriend'),
            'manage_options',
            'jefrssfriend',
            array($this, 'render_articles_page'),
            'dashicons-rss',
            3
        );
        
        // 子菜单
        add_submenu_page(
            'jefrssfriend',
            __('文章列表', 'jefrssfriend'),
            __('文章列表', 'jefrssfriend'),
            'manage_options',
            'jefrssfriend',
            array($this, 'render_articles_page')
        );
        
        // 阅读页面保持隐藏
        add_submenu_page(
            null,  // 设为 null 使其不显示在菜单中
            __('阅读文章', 'jefrssfriend'),
            __('阅读文章', 'jefrssfriend'),
            'manage_options',
            'jefrssfriend-reader',
            function() {
                require_once JEFRSSFRIEND_PATH . 'admin/views/reader-center.php';
                $reader_view = new JefRSSFriend_Reader_View();
                $reader_view->render();
            }
        );
        
        add_submenu_page(
            'jefrssfriend',
            __('站点管理', 'jefrssfriend'),
            __('站点管理', 'jefrssfriend'),
            'manage_options',
            'jefrssfriend-sites',
            array($this, 'render_sites_page')
        );
        
        add_submenu_page(
            'jefrssfriend',
            __('分组管理', 'jefrssfriend'),
            __('分组管理', 'jefrssfriend'),
            'manage_options',
            'jefrssfriend-groups',
            array($this, 'render_groups_page')
        );
        
        // 在分组管理菜单后添加导入导出菜单
        add_submenu_page(
            'jefrssfriend',
            __('导入导出', 'jefrssfriend'),
            __('导入导出', 'jefrssfriend'), 
            'manage_options',
            'jefrssfriend-import',
            array($this, 'render_import_page')
        );
        
        add_submenu_page(
            'jefrssfriend',
            __('设置中心', 'jefrssfriend'),
            __('设置中心', 'jefrssfriend'),
            'manage_options',
            'jefrssfriend-settings',
            array($this->settings, 'render_settings_page')
        );
        
        // 添加日志中心子菜单
        add_submenu_page(
            'jefrssfriend',
            __('日志中心', 'jefrssfriend'),
            __('日志中心', 'jefrssfriend'),
            'manage_options',
            'jefrssfriend-logs',
            array($this, 'render_logs_page')
        );

        // 添加移动端阅读页面（隐藏菜单）
        add_submenu_page(
            null,  // 设为 null 使其不显示在菜单中
            __('移动阅读', 'jefrssfriend'),
            __('移动阅读', 'jefrssfriend'),
            'manage_options',
            'jefrssfriend-reader-mobile',
            array($this, 'render_mobile_reader_view')
        );
    }
    
    public function render_settings_page() {
        $this->settings->render_settings_page();
    }
    
    /**
     * 加载管理界面资源
     */
    public function enqueue_admin_assets($hook) {
        // 检查是否是插件的页面
        if (strpos($hook, 'jefrssfriend') !== false) {
            // 加载管理界面通用样式
            wp_enqueue_style(
                'jefrssfriend-admin',
                JEFRSSFRIEND_URL . 'assets/css/admin.css',
                array(),
                JEFRSSFRIEND_VERSION
            );
            
            // 检查是否是阅读页面或移动端阅读页面
            if (isset($_GET['page']) && 
                ($_GET['page'] === 'jefrssfriend-reader' || $_GET['page'] === 'jefrssfriend-reader-mobile')) {
                
                // 加载基础阅读中心样式 (PC端)
                wp_enqueue_style(
                    'jefrssfriend-reader-center',
                    JEFRSSFRIEND_URL . 'admin/css/reader-center.css',
                    array(),
                    JEFRSSFRIEND_VERSION
                );
                
                // 如果是移动端页面，额外加载移动端样式
                if ($_GET['page'] === 'jefrssfriend-reader-mobile') {
                    wp_enqueue_style(
                        'jefrssfriend-mobile-reader',
                        JEFRSSFRIEND_URL . 'assets/css/reader-center-mobile.css', // 修改为正确的移动端样式路径
                        array(),  // 移除对基础样式的依赖，因为类名已独立
                        JEFRSSFRIEND_VERSION
                    );
                    
                    // 加载移动端脚本
                    wp_enqueue_script(
                        'jefrssfriend-mobile-reader',
                        JEFRSSFRIEND_URL . 'assets/js/mobile-reader.js',
                        array('jquery', 'jefrssfriend-admin'),
                        JEFRSSFRIEND_VERSION,
                        true
                    );
                }
            }
            
            // 加载管理界面脚本
            wp_enqueue_script(
                'jefrssfriend-admin',
                JEFRSSFRIEND_URL . 'assets/js/admin.js',
                array('jquery'),
                JEFRSSFRIEND_VERSION,
                true
            );
            
            // 添加nonce和AJAX URL
            wp_localize_script('jefrssfriend-admin', 'jefrssfriend', array(
                'ajax_url' => admin_url('admin-ajax.php'),
                'nonce' => wp_create_nonce('jefrssfriend-admin')
            ));
        }
        
        // 移动端页面加载
        if (isset($_GET['page']) && $_GET['page'] === 'jefrssfriend-reader-mobile') {
            // 允许同时加载PC和移动端样式，但确保移动端样式优先级更高
            wp_enqueue_style(
                'jefrssfriend-reader-center',
                JEFRSSFRIEND_URL . 'admin/css/reader-center.css',
                array(),
                JEFRSSFRIEND_VERSION
            );
            
            wp_enqueue_style(
                'jefrssfriend-mobile-reader',
                JEFRSSFRIEND_URL . 'admin/css/reader-center-mobile.css',
                array('jefrssfriend-reader-center'),
                JEFRSSFRIEND_VERSION
            );
        }
    }
    
    public function render_articles_page() {
        global $wpdb;
        
        // 获取筛选参数
        $site_id = isset($_GET['site_id']) ? intval($_GET['site_id']) : 0;
        $group_id = isset($_GET['group_id']) ? intval($_GET['group_id']) : 0;
        
        // 分页设置
        $per_page = 20;
        $current_page = isset($_GET['paged']) ? max(1, intval($_GET['paged'])) : 1;
        $offset = ($current_page - 1) * $per_page;
        
        // 构建查询条件
        $where = array();
        $where_values = array();
        
        if ($site_id) {
            $where[] = 'a.site_id = %d';
            $where_values[] = $site_id;
        }
        
        if ($group_id) {
            $where[] = 's.group_id = %d';
            $where_values[] = $group_id;
        }
        
        $where_clause = !empty($where) ? 'WHERE ' . implode(' AND ', $where) : '';
        
        // 获取总记录数
        $count_query = $wpdb->prepare(
            "SELECT COUNT(DISTINCT a.id) 
            FROM {$wpdb->prefix}jefrss_articles a
            LEFT JOIN {$wpdb->prefix}jefrss_sites s ON a.site_id = s.id
            $where_clause",
            $where_values
        );
        
        $total_items = $wpdb->get_var($count_query);
        
        // 获取文章列表
        $query = $wpdb->prepare(
            "SELECT a.*, s.title as site_title, s.site_url, g.name as group_name
            FROM {$wpdb->prefix}jefrss_articles a
            LEFT JOIN {$wpdb->prefix}jefrss_sites s ON a.site_id = s.id
            LEFT JOIN {$wpdb->prefix}jefrss_groups g ON s.group_id = g.id
            $where_clause
            ORDER BY a.pub_date DESC
            LIMIT %d OFFSET %d",
            array_merge($where_values, array($per_page, $offset))
        );
        
        $articles = $wpdb->get_results($query);
        
        // 获取所有站点和分组（用于筛选下拉框）
        $sites = $wpdb->get_results("SELECT id, title FROM {$wpdb->prefix}jefrss_sites ORDER BY title");
        $groups = $wpdb->get_results("SELECT id, name FROM {$wpdb->prefix}jefrss_groups ORDER BY order_num");
        
        // 计算总页数
        $total_pages = ceil($total_items / $per_page);
        
        // 加载视图
        include JEFRSSFRIEND_PATH . 'admin/views/articles-page.php';
    }
    
    public function render_sites_page() {
        global $wpdb;
        
        // 分页设置
        $per_page = 40; // 每页显示数量
        $current_page = isset($_GET['paged']) ? max(1, intval($_GET['paged'])) : 1;
        $offset = ($current_page - 1) * $per_page;
        
        // 获取总数
        $total_items = $wpdb->get_var("
            SELECT COUNT(*) 
            FROM {$wpdb->prefix}jefrss_sites
        ");
        
        $total_pages = ceil($total_items / $per_page);
        
        // 获取所有站点
        $sites = $wpdb->get_results("
            SELECT s.*, g.name as group_name 
            FROM {$wpdb->prefix}jefrss_sites s 
            LEFT JOIN {$wpdb->prefix}jefrss_groups g ON s.group_id = g.id 
            ORDER BY s.title
            LIMIT $per_page OFFSET $offset
        ");
        
        // 获取所有分组供下拉选择
        $groups = $wpdb->get_results("
            SELECT * FROM {$wpdb->prefix}jefrss_groups 
            ORDER BY order_num, name
        ");
        
        // 设置模板变量
        $data = array(
            'sites' => $sites,
            'groups' => $groups,
            'total_items' => $total_items,
            'total_pages' => $total_pages,
            'current_page' => $current_page,
            'per_page' => $per_page
        );
        
        include JEFRSSFRIEND_PATH . 'admin/views/sites-page.php';
    }
    
    public function render_groups_page() {
        include JEFRSSFRIEND_PATH . 'admin/views/groups-page.php';
    }
    
    public function render_import_page() {
        include JEFRSSFRIEND_PATH . 'admin/views/import-page.php';
    }

    
    /**
     * 抓取所有RSS源的文章
     */
    public function refresh_all_feeds() {
        global $wpdb;
        
        // 获取活跃站点
        $sites = $wpdb->get_results("
            SELECT * FROM {$wpdb->prefix}jefrss_sites 
            WHERE status = 'active'
        ");

        $total_articles = 0;
        foreach ($sites as $site) {
            $articles = $this->fetch_feed($site);
            if (!empty($articles)) {
                foreach ($articles as $article) {
                    if ($this->save_article($site->id, $article)) {
                        $total_articles++;
                    }
                }
            }
        }
        
        error_log("刷新完成，共获取 {$total_articles} 篇文章");
        return $total_articles;
    }
    
    /**
     * 抓取单个RSS源的文章
     */
    private function fetch_feed($site) {
        try {
            // 获取设置的文章数量限制
            $options = get_option('jefrssfriend_options');
            $articles_per_feed = isset($options['articles_per_feed']) ? intval($options['articles_per_feed']) : 10;
            
            error_log("开始获取源 {$site->title} 的文章，限制: {$articles_per_feed} 篇");
            
            $rss = fetch_feed($site->rss_url);
            if (is_wp_error($rss)) {
                throw new Exception($rss->get_error_message());
            }
            
            // 设置 SimplePie 的文章获取数量限制
            if ($rss instanceof SimplePie) {
                $rss->set_item_limit($articles_per_feed);
                $rss->enable_cache(false);
                $rss->init();
            }
            
            // 获取文章列表
            $items = $rss->get_items(0, $articles_per_feed);
            $articles = array();
            
            foreach ($items as $item) {
                // 获取完整的HTML内容
                $content = $item->get_content();
                
                $articles[] = array(
                    'title' => $item->get_title(),
                    'url' => $item->get_permalink(),
                    'content' => $content,
                    'date' => $item->get_date('Y-m-d H:i:s'),
                    'description' => $item->get_description()
                );
            }
            
            error_log("源 {$site->title} 获取完成，共获取 " . count($articles) . " 篇文章");
            return $articles;
            
        } catch (Exception $e) {
            error_log('RSS获取错误: ' . $e->getMessage());
            return array();
        }
    }
    
    /**
     * 从文章内容中提取图片URL
     */
    private function extract_images($content) {
        $images = array();
        preg_match_all('/<img[^>]+src=([\'"])?((http|https):\/\/[^\'"]+)\\1/i', $content, $matches);
        if (!empty($matches[2])) {
            $images = array_unique($matches[2]);
        }
        return $images;
    }
    
    /**
     * 缓存图片到本地
     */
    private function cache_image($url) {
        $cache_dir = JEFRSSFRIEND_PATH . 'data/cache/images/' . substr(md5($url), 0, 2);
        if (!file_exists($cache_dir)) {
            mkdir($cache_dir, 0755, true);
        }
        
        $file_name = md5($url) . '.' . pathinfo(parse_url($url, PHP_URL_PATH), PATHINFO_EXTENSION);
        $cache_path = $cache_dir . '/' . $file_name;
        
        if (!file_exists($cache_path)) {
            $response = wp_remote_get($url);
            if (!is_wp_error($response) && wp_remote_retrieve_response_code($response) === 200) {
                file_put_contents($cache_path, wp_remote_retrieve_body($response));
            } else {
                return false;
            }
        }
        
        return str_replace(JEFRSSFRIEND_PATH, '', $cache_path);
    }
    
    /**
     * 更新JSON缓存
     */
    private function update_json_cache() {
        try {
            // 获取核心类实例
            $core = new JefRSSFriend_Lite_Core();
            
            // 生成新的 JSON 数据
            $json_data = $core->generate_json();
            if (!$json_data) {
                throw new Exception('生成 JSON 数据失败');
            }
            
            // 保存到文件
            $json_file = JEFRSSFRIEND_PATH . 'data/latest.json';
            if (file_put_contents($json_file, $json_data) === false) {
                throw new Exception('保存 JSON 文件失败');
            }
            
            error_log('JSON 缓存更新成功');
            return true;
            
        } catch (Exception $e) {
            error_log('更新 JSON 缓存失败: ' . $e->getMessage());
            return false;
        }
    }
    
    private function get_articles_batch($offset, $limit) {
        global $wpdb;
        return $wpdb->get_results($wpdb->prepare("
            SELECT a.*, s.title as site_title, s.icon_url
            FROM {$wpdb->prefix}jefrss_articles a
            JOIN {$wpdb->prefix}jefrss_sites s ON a.site_id = s.id
            WHERE s.status = 'active'
            ORDER BY a.pub_date DESC
            LIMIT %d OFFSET %d
        ", $limit, $offset));
    }
    
    /**
     * AJAX刷新RSS源
     */
    public function ajax_refresh_feeds() {
        check_ajax_referer('jefrssfriend-admin');
        
        if (!current_user_can('manage_options')) {
            wp_send_json_error(array('message' => '权限不足'));
            return;
        }
        
        try {
            // 获取偏移量
            $offset = isset($_POST['offset']) ? intval($_POST['offset']) : 0;
            // 每批处理的数量
            $batch_size = 5;  // 每次只处理5个源
            
            // 获取所有活跃的RSS源
            global $wpdb;
            $sites = $wpdb->get_results($wpdb->prepare("
                SELECT * FROM {$wpdb->prefix}jefrss_sites 
                WHERE status = 'active'
                LIMIT %d OFFSET %d
            ", $batch_size, $offset));
            
            $total_sites = $wpdb->get_var("
                SELECT COUNT(*) FROM {$wpdb->prefix}jefrss_sites 
                WHERE status = 'active'
            ");
            
            // 防止除以零错误
            if ($total_sites === 0) {
                wp_send_json_error(array(
                    'message' => '没有活跃的RSS源',
                    'progress' => 0,
                    'total' => 0
                ));
                return;
            }
            
            $articles_count = 0;
            foreach ($sites as $site) {
                $articles = $this->fetch_feed($site);
                if (!empty($articles)) {
                    foreach ($articles as $article) {
                        if ($this->save_article($site->id, $article)) {
                            $articles_count++;
                        }
                    }
                }
            }
            
            // 计算进度
            $progress = round(($offset + count($sites)) / $total_sites * 100);
            
            // 如果是最后一批，更新JSON缓存
            if ($offset + count($sites) >= $total_sites) {
                $this->update_json_cache();
                error_log('RSS刷新完成，已更新JSON缓存');
            }
            
            wp_send_json_success(array(
                'message' => sprintf('已处理 %d 个源，获取 %d 篇文章', count($sites), $articles_count),
                'progress' => $progress,
                'total' => $total_sites,
                'processed' => $offset + count($sites),
                'articles' => $articles_count
            ));
            
        } catch (Exception $e) {
            wp_send_json_error(array(
                'message' => $e->getMessage(),
                'offset' => $offset
            ));
        }
    }
    
    /**
     * 获取单个RSS源的文章
     */
    private function get_feed_articles($site) {
        if (empty($site->rss_url)) {
            throw new Exception('RSS地址为空');
        }
        
        $rss = fetch_feed($site->rss_url);
        if (is_wp_error($rss)) {
            throw new Exception($rss->get_error_message());
        }
        
        // 设置每个源最多获取的文章数
        $articles_per_feed = 5;  // 每个源只获取最新的5篇文章
        
        if ($rss instanceof SimplePie) {
            $rss->set_item_limit($articles_per_feed);
            $rss->set_timeout(10);  // 设置获取超时时间
            $rss->enable_cache(false);
            $rss->init();
        }
        
        $items = $rss->get_items(0, $articles_per_feed);
        $articles = array();
        
        foreach ($items as $item) {
            $articles[] = array(
                'title' => $item->get_title(),
                'link' => $item->get_permalink(),
                'description' => $item->get_description(),
                'content' => $item->get_content(),
                'pub_date' => $item->get_date('Y-m-d H:i:s'),
                'site_title' => $site->title,
                'site_url' => $site->site_url,
                'icon_url' => $site->icon_url
            );
        }
        
        return $articles;
    }
    
    /**
     * 保存文章到数据库
     */
    private function save_article($site_id, $article_data) {
        global $wpdb;
        
        try {
            // 处理description，确保是纯文本
            $description = !empty($article_data['description']) 
                ? wp_strip_all_tags($article_data['description'])
                : wp_strip_all_tags($article_data['content']);
            
            // 生成文章哈希
            $article_hash = md5(
                $site_id . 
                $article_data['url'] . 
                $article_data['date']
            );
            
            // 检查文章是否已存在
            $exists = $wpdb->get_var($wpdb->prepare(
                "SELECT id FROM {$wpdb->prefix}jefrss_articles 
                WHERE site_id = %d 
                AND article_hash = %s",
                $site_id,
                $article_hash
            ));
            
            if ($exists) {
                error_log('文章已存在，跳过: ' . $article_data['url']);
                return false;
            }
            
            // 插入新文章
            $result = $wpdb->insert(
                $wpdb->prefix . 'jefrss_articles',
                array(
                    'site_id' => $site_id,
                    'title' => $article_data['title'],
                    'link' => $article_data['url'],
                    'content' => $article_data['content'],
                    'description' => $description,  // 存储处理后的纯文本描述
                    'pub_date' => $article_data['date'],
                    'article_hash' => $article_hash
                ),
                array('%d', '%s', '%s', '%s', '%s', '%s', '%s')
            );
            
            if ($result === false) {
                throw new Exception($wpdb->last_error);
            }
            
            error_log('成功保存新文章: ' . $article_data['title']);
            return $wpdb->insert_id;
            
        } catch (Exception $e) {
            error_log('保存文章失败: ' . $e->getMessage());
            return false;
        }
    }
    
    // 缓存单个图片
    private function cache_single_image($image_url, $site_id) {
        if (empty($image_url)) return '';
        
        $upload_dir = wp_upload_dir();
        $cache_dir = $upload_dir['basedir'] . '/jefrss/images/' . $site_id;
        
        if (!file_exists($cache_dir)) {
            wp_mkdir_p($cache_dir);
        }
        
        $img_hash = md5($image_url);
        $ext = pathinfo(parse_url($image_url, PHP_URL_PATH), PATHINFO_EXTENSION);
        $ext = $ext ? $ext : 'jpg';
        
        $new_filename = $img_hash . '.' . $ext;
        $cached_path = $cache_dir . '/' . $new_filename;
        $cached_url = $upload_dir['baseurl'] . '/jefrss/images/' . $site_id . '/' . $new_filename;
        
        if (!file_exists($cached_path)) {
            $response = wp_safe_remote_get($image_url);
            if (!is_wp_error($response) && wp_remote_retrieve_response_code($response) === 200) {
                file_put_contents($cached_path, wp_remote_retrieve_body($response));
                return $cached_url;
            }
        } else {
            return $cached_url;
        }
        
        return $image_url; // 如果缓存失败，返回原始URL
    }
    
    public function ajax_delete_site() {
        error_log('Starting delete_site');
        check_ajax_referer('jefrssfriend-admin');
        
        if (!current_user_can('manage_options')) {
            wp_send_json_error('权限不足');
        }
        
        $site_id = absint($_POST['id']);
        
        try {
            global $wpdb;
            
            error_log('Deleting site: ' . $site_id);
            $result = $wpdb->delete(
                $wpdb->prefix . 'jefrss_sites',
                array('id' => $site_id),
                array('%d')
            );
            
            if ($result === false) {
                error_log('Delete failed: ' . $wpdb->last_error);
                throw new Exception('删除站点失败');
            }
            
            error_log('Delete successful');
            wp_send_json_success('删除站点成功');
            
        } catch (Exception $e) {
            error_log('Delete exception: ' . $e->getMessage());
            wp_send_json_error($e->getMessage());
        }
    }
    
    /**
     * 处理添加RSS站点的表单提交
     */
    public function handle_add_site() {
        // 验证nonce
        check_admin_referer('jefrssfriend-admin');
        
        // 验证权限
        if (!current_user_can('manage_options')) {
            wp_die('权限不足');
        }
        
        global $wpdb;
        
        // 处理数据
        $site_data = array(
            'title' => sanitize_text_field($_POST['title']),
            'rss_url' => esc_url_raw($_POST['rss_url']),
            'site_url' => esc_url_raw($_POST['site_url']),
            'status' => 'active'
        );
        
        // 可选字段
        if (!empty($_POST['group_id'])) {
            $site_data['group_id'] = absint($_POST['group_id']);
        }
        
        // 插入数据
        $result = $wpdb->insert(
            $wpdb->prefix . 'jefrss_sites',
            $site_data,
            array_fill(0, count($site_data), '%s')
        );
        
        // 处理结果
        if ($result === false) {
            // 保存失败
            wp_redirect(add_query_arg(
                array('page' => 'jefrssfriend-sites', 'error' => '1'),
                admin_url('admin.php')
            ));
            exit;
        }
        
        // 保存成功
        wp_redirect(add_query_arg(
            array('page' => 'jefrssfriend-sites', 'success' => '1'),
            admin_url('admin.php')
        ));
        exit;
    }
    
    /**
     * 处理添加分组的表单提交
     */
    public function handle_add_group() {
        check_admin_referer('jefrssfriend-admin');
        
        if (!current_user_can('manage_options')) {
            wp_die('权限不足');
        }
        
        global $wpdb;
        
        $group_data = array(
            'name' => sanitize_text_field($_POST['name']),
            'description' => sanitize_textarea_field($_POST['description'])
        );
        
        $result = $wpdb->insert(
            $wpdb->prefix . 'jefrss_groups',
            $group_data,
            array('%s', '%s')
        );
        
        if ($result === false) {
            wp_redirect(add_query_arg(
                array('page' => 'jefrssfriend-groups', 'error' => '1'),
                admin_url('admin.php')
            ));
            exit;
        }
        
        wp_redirect(add_query_arg(
            array('page' => 'jefrssfriend-groups', 'success' => '1'),
            admin_url('admin.php')
        ));
        exit;
    }
    
    /**
     * 处理OPML导入的表单提交
     */
    public function handle_import_opml() {
        check_admin_referer('jefrssfriend-admin');
        
        if (!current_user_can('manage_options')) {
            wp_die('权限不足');
        }
        
        global $wpdb;
        $imported = 0;
        $imported_groups = 0;
        
        try {
            if (!isset($_FILES['opml_file'])) {
                throw new Exception('未上传文件');
            }
            
            $xml = simplexml_load_file($_FILES['opml_file']['tmp_name']);
            if (!$xml) {
                throw new Exception('OPML解析失败');
            }
            
            // 处理分组和订阅源
            foreach ($xml->body->outline as $group) {
                if (isset($group['xmlUrl'])) { // 这是一个没有分组的订阅源
                    $this->import_feed($group, null);
                    $imported++;
                } else if ((string)$group['text'] !== '') { // 这是一个有效的分组
                    // 这是一个分组
                    $group_id = $this->create_or_get_group((string)$group['text']);
                    $imported_groups++;
                    
                    // 处理分组下的订阅源
                    foreach ($group->outline as $feed) {
                        if (isset($feed['xmlUrl'])) {
                            $this->import_feed($feed, $group_id);
                            $imported++;
                        }
                    }
                }
            }
            
            wp_redirect(add_query_arg(
                array(
                    'page' => 'jefrssfriend-import',
                    'success' => '1',
                    'imported' => $imported,
                    'groups' => $imported_groups
                ),
                admin_url('admin.php')
            ));
            exit;
            
        } catch (Exception $e) {
            wp_redirect(add_query_arg(
                array('page' => 'jefrssfriend-import', 'error' => 'parse'),
                admin_url('admin.php')
            ));
            exit;
        }
    }
    
    private function create_or_get_group($group_name) {
        global $wpdb;
        
        // 检查分组是否已存在
        $group = $wpdb->get_row($wpdb->prepare(
            "SELECT id FROM {$wpdb->prefix}jefrss_groups WHERE name = %s",
            $group_name
        ));
        
        if ($group) {
            return $group->id;
        }
        
        // 创建新分组
        $wpdb->insert(
            $wpdb->prefix . 'jefrss_groups',
            array('name' => $group_name),
            array('%s')
        );
        
        return $wpdb->insert_id;
    }
    
    private function import_feed($feed, $group_id) {
        global $wpdb;
        
        // 确保所有必要的属性都存在
        $feed_data = array(
            'title' => (string)($feed['text'] ?? $feed['title'] ?? ''),
            'rss_url' => (string)($feed['xmlUrl'] ?? ''),
            'site_url' => (string)($feed['htmlUrl'] ?? ''),
            'status' => 'active',  // 确保状态为激活
            'group_id' => $group_id
        );
        
        // 检查RSS源是否已存在
        $exists = $wpdb->get_var($wpdb->prepare(
            "SELECT id FROM {$wpdb->prefix}jefrss_sites WHERE rss_url = %s",
            $feed_data['rss_url']
        ));
        
        if (!$exists) {
            $wpdb->insert(
                $wpdb->prefix . 'jefrss_sites',
                $feed_data,
                array(
                    '%s',  // title
                    '%s',  // rss_url
                    '%s',  // site_url
                    '%s',  // status
                    '%d'   // group_id
                )
            );
            
            error_log('导入RSS源: ' . print_r($feed_data, true));
            
            // 验证插入是否成功
            if ($wpdb->last_error) {
                error_log('导入失败: ' . $wpdb->last_error);
            } else {
                error_log('成功导入并激活站点: ' . $feed_data['title']);
            }
        }
    }
    
    /**
     * 处理OPML导出
     */
    public function handle_export_opml() {
        check_admin_referer('jefrssfriend-export');
        
        global $wpdb;
        
        // 获取所有站点和分组信息
        $sites = $wpdb->get_results("
            SELECT s.*, g.name as group_name 
            FROM {$wpdb->prefix}jefrss_sites s
            LEFT JOIN {$wpdb->prefix}jefrss_groups g ON s.group_id = g.id
            WHERE s.status = 'active' 
            ORDER BY g.name, s.title
        ");
        
        // 生成OPML
        $opml = '<?xml version="1.0" encoding="UTF-8"?>
<opml version="1.0">
    <head>
        <title>RSS订阅导出</title>
        <dateCreated>' . date('r') . '</dateCreated>
    </head>
    <body>';
        
        // 按分组组织输出
        $current_group = '';
        foreach ($sites as $site) {
            if ($site->group_name && $site->group_name !== $current_group) {
                if ($current_group !== '') {
                    $opml .= "    </outline>\n";
                }
                $opml .= sprintf('    <outline text="%s" title="%s">', 
                    esc_attr($site->group_name), 
                    esc_attr($site->group_name)
                );
                $current_group = $site->group_name;
            }
            
            $opml .= sprintf(
                '        <outline text="%s" title="%s" type="rss" xmlUrl="%s" htmlUrl="%s"/>',
                esc_attr($site->title),
                esc_attr($site->title),
                esc_attr($site->rss_url),
                esc_attr($site->site_url)
            );
        }
        
        if ($current_group !== '') {
            $opml .= "    </outline>\n";
        }
        
        $opml .= '</body>
</opml>';
        
        // 输出OPML文件
        header('Content-Type: text/xml');
        header('Content-Disposition: attachment; filename="rss-export-' . date('Y-m-d') . '.opml"');
        echo $opml;
        exit;
    }
    
    /**
     * AJAX获取站点数据
     */
    public function ajax_get_site() {
        error_log('Getting site data...');
        check_ajax_referer('jefrssfriend-admin');
        
        if (!current_user_can('manage_options')) {
            error_log('Permission denied');
            wp_send_json_error('权限不足');
        }
        
        $site_id = absint($_POST['id']);
        error_log('Site ID: ' . $site_id);
        
        global $wpdb;
        $site = $wpdb->get_row($wpdb->prepare(
            "SELECT * FROM {$wpdb->prefix}jefrss_sites WHERE id = %d",
            $site_id
        ));
        
        if (!$site) {
            error_log('Site not found');
            wp_send_json_error('站点不存在');
            return;
        }
        
        error_log('Site found: ' . print_r($site, true));
        wp_send_json_success($site);
    }
    
    public function render_reader_page() {
        include JEFRSSFRIEND_PATH . 'admin/views/reader-page.php';
    }
    
    /**
     * 处理清理文章的请求
     */
    public function handle_cleanup_articles() {
        // 验证nonce
        check_admin_referer('jefrssfriend_cleanup');
        
        // 验证权限
        if (!current_user_can('manage_options')) {
            wp_die('权限不足');
        }
        
        global $wpdb;
        
        try {
            // 获取设置
            $options = get_option('jefrssfriend_options');
            $cache_size = isset($options['cache_size']) ? intval($options['cache_size']) : 10;
            
            // 获取所有活跃站点
            $sites = $wpdb->get_results("
                SELECT id, title FROM {$wpdb->prefix}jefrss_sites 
                WHERE status = 'active'
            ");
            
            $cleaned = 0;
            foreach ($sites as $site) {
                // 获取当前文章数
                $before = $wpdb->get_var($wpdb->prepare(
                    "SELECT COUNT(*) FROM {$wpdb->prefix}jefrss_articles WHERE site_id = %d",
                    $site->id
                ));
                
                // 清理旧文章
                $wpdb->query($wpdb->prepare("
                    DELETE FROM {$wpdb->prefix}jefrss_articles 
                    WHERE site_id = %d 
                    AND id NOT IN (
                        SELECT id FROM (
                            SELECT id 
                            FROM {$wpdb->prefix}jefrss_articles 
                            WHERE site_id = %d 
                            ORDER BY pub_date DESC 
                            LIMIT %d
                        ) temp
                    )",
                    $site->id,
                    $site->id,
                    $cache_size
                ));
                
                // 计算清理数量
                $after = $wpdb->get_var($wpdb->prepare(
                    "SELECT COUNT(*) FROM {$wpdb->prefix}jefrss_articles WHERE site_id = %d",
                    $site->id
                ));
                
                $cleaned += ($before - $after);
            }
            
            // 设置成功消息
            add_settings_error(
                'jefrssfriend_messages',
                'cleanup_success',
                sprintf('成功清理了 %d 篇旧文章', $cleaned),
                'updated'
            );
            
        } catch (Exception $e) {
            // 设置错误消息
            add_settings_error(
                'jefrssfriend_messages',
                'cleanup_error',
                '清理文章时出错：' . $e->getMessage(),
                'error'
            );
        }
        
        // 重定向回设置页面
        wp_redirect(add_query_arg(array(
            'page' => 'jefrssfriend-settings',
            'settings-updated' => 'true'
        ), admin_url('admin.php')));
        exit;
    }
    
    /**
     * AJAX处理清理文章请求
     */
    public function ajax_cleanup_articles() {
        check_ajax_referer('jefrssfriend_cleanup');
        
        if (!current_user_can('manage_options')) {
            wp_send_json_error(array('message' => '权限不足'));
        }
        
        global $wpdb;
        
        try {
            $options = get_option('jefrssfriend_options');
            $cache_size = isset($options['cache_size']) ? intval($options['cache_size']) : 10;
            
            $sites = $wpdb->get_results("
                SELECT id, title FROM {$wpdb->prefix}jefrss_sites 
                WHERE status = 'active'
            ");
            
            $cleaned = 0;
            foreach ($sites as $site) {
                $before = $wpdb->get_var($wpdb->prepare(
                    "SELECT COUNT(*) FROM {$wpdb->prefix}jefrss_articles WHERE site_id = %d",
                    $site->id
                ));
                
                $wpdb->query($wpdb->prepare("
                    DELETE FROM {$wpdb->prefix}jefrss_articles 
                    WHERE site_id = %d 
                    AND id NOT IN (
                        SELECT id FROM (
                            SELECT id 
                            FROM {$wpdb->prefix}jefrss_articles 
                            WHERE site_id = %d 
                            ORDER BY pub_date DESC 
                            LIMIT %d
                        ) temp
                    )",
                    $site->id,
                    $site->id,
                    $cache_size
                ));
                
                $after = $wpdb->get_var($wpdb->prepare(
                    "SELECT COUNT(*) FROM {$wpdb->prefix}jefrss_articles WHERE site_id = %d",
                    $site->id
                ));
                
                $cleaned += ($before - $after);
            }
            
            wp_send_json_success(array('cleaned' => $cleaned));
            
        } catch (Exception $e) {
            wp_send_json_error(array('message' => $e->getMessage()));
        }
    }
    
    public function save_site($data) {
        global $wpdb;
        
        // 调试输出
        error_log('Save site function data: ' . print_r($data, true));
        
        // 检查是否是编辑模式
        $is_edit = !empty($data['id']);
        error_log('Is edit mode: ' . ($is_edit ? 'yes' : 'no'));
        
        if ($is_edit) {
            // 验证站点是否存在
            $existing_site = $wpdb->get_row($wpdb->prepare(
                "SELECT * FROM {$wpdb->prefix}jefrss_sites WHERE id = %d",
                $data['id']
            ));
            
            if (!$existing_site) {
                return new WP_Error('site_not_found', __('站点不存在', 'jefrssfriend'));
            }
            
            // 检查RSS URL是否被其他站点使用
            $duplicate = $wpdb->get_var($wpdb->prepare(
                "SELECT id FROM {$wpdb->prefix}jefrss_sites 
                WHERE rss_url = %s AND id != %d",
                $data['rss_url'],
                $data['id']
            ));
            
            if ($duplicate) {
                return new WP_Error('duplicate_site', __('该RSS源已被其他站点使用', 'jefrssfriend'));
            }
        }
        
        // 处理 group_id
        $group_id = isset($data['group_id']) ? absint($data['group_id']) : null;
        
        // 准备数据
        $site_data = array(
            'title' => $data['title'],
            'rss_url' => $data['rss_url'],
            'site_url' => $data['site_url'],
            'icon_url' => $data['icon_url'],
            'group_id' => $group_id,
            'status' => 'active'
        );
        
        // 调试输出
        error_log('Prepared site data: ' . print_r($site_data, true));
        
        if ($is_edit) {
            // 更新站点
            error_log('Updating existing site with ID: ' . $data['id']);
            $result = $wpdb->update(
                $wpdb->prefix . 'jefrss_sites',
                $site_data,
                array('id' => $data['id']),
                array('%s', '%s', '%s', '%s', '%d', '%s'),
                array('%d')
            );
            
            error_log('Update result: ' . var_export($result, true));
            error_log('Last DB error: ' . $wpdb->last_error);
            
            return $result !== false ? $data['id'] : false;
        }
        
        // 检查是否已存在相同的RSS URL（仅在新增时）
        $existing = $wpdb->get_var($wpdb->prepare(
            "SELECT id FROM {$wpdb->prefix}jefrss_sites WHERE rss_url = %s",
            $data['rss_url']
        ));
        
        if ($existing) {
            return new WP_Error('duplicate_site', __('该RSS源已存在', 'jefrssfriend'));
        }
        
        // 新增站点
        $result = $wpdb->insert(
            $wpdb->prefix . 'jefrss_sites',
            $site_data,
            array('%s', '%s', '%s', '%s', '%d', '%s')
        );
        
        return $result ? $wpdb->insert_id : false;
    }
    
    public function handle_site_form() {
        if (!isset($_POST['submit_site'])) {
            return;
        }
        
        check_admin_referer('save_site');
        
        // 调试输出
        error_log('POST data for site save: ' . print_r($_POST, true));
        
        $site_data = array(
            'title' => sanitize_text_field($_POST['title']),
            'rss_url' => esc_url_raw($_POST['rss_url']),
            'site_url' => esc_url_raw($_POST['site_url']),
            'icon_url' => esc_url_raw($_POST['icon_url']),
            'group_id' => isset($_POST['group_id']) ? absint($_POST['group_id']) : null
        );
        
        // 如果是编辑现有站点
        if (!empty($_POST['site_id'])) {
            $site_data['id'] = absint($_POST['site_id']);
        }
        
        // 调试输出处理后的数据
        error_log('Processed site data: ' . print_r($site_data, true));
        
        $result = $this->save_site($site_data);
        
        // 调试输出保存结果
        error_log('Save result: ' . print_r($result, true));
        
        if (is_wp_error($result)) {
            wp_redirect(add_query_arg(array(
                'page' => 'jefrssfriend-sites',
                'error' => urlencode($result->get_error_message())
            ), admin_url('admin.php')));
            exit;
        }
        
        // 确保更新成功
        if ($result === false) {
            wp_redirect(add_query_arg(array(
                'page' => 'jefrssfriend-sites',
                'error' => urlencode('保存失败，请重试')
            ), admin_url('admin.php')));
            exit;
        }
        
        // 成功保存后刷新页面
        wp_redirect(add_query_arg(array(
            'page' => 'jefrssfriend-sites',
            'success' => 1,
            'site_id' => $result
        ), admin_url('admin.php')));
        exit;
    }
    
    /**
     * 处理文章中的图片
     */
    private function process_article_images($content, $site_id) {
        if (empty($content)) {
            return $content;
        }
        
        // 查找所有图片标签
        preg_match_all('/<img[^>]+>/i', $content, $matches);
        
        foreach ($matches[0] as $img_tag) {
            // 提取图片URL
            preg_match('/src=[\'"]([^\'"]+)[\'"]/i', $img_tag, $src);
            if (empty($src[1])) continue;
            
            $original_url = $src[1];
            
            // 验证图片URL是否有效
            $response = wp_remote_head($original_url);
            if (is_wp_error($response) || wp_remote_retrieve_response_code($response) !== 200) {
                // 如果图片无效，移除图片标签
                $content = str_replace($img_tag, '', $content);
                continue;
            }
            
            // 确保图片URL是HTTPS
            if (strpos($original_url, 'http://') === 0) {
                $https_url = str_replace('http://', 'https://', $original_url);
                $new_img_tag = str_replace($original_url, $https_url, $img_tag);
                $content = str_replace($img_tag, $new_img_tag, $content);
            }
            
            // 添加延迟加载属性
            if (strpos($img_tag, 'loading=') === false) {
                $new_img_tag = str_replace('<img', '<img loading="lazy"', $img_tag);
                $content = str_replace($img_tag, $new_img_tag, $content);
            }
        }
        
        return $content;
    }
    
    public function enqueue_reader_assets() {
        $screen = get_current_screen();
        
        // 只在阅读页面加载
        if ($screen && $screen->id === 'admin_page_jefrssfriend-reader') {
            // 已有的CSS
            wp_enqueue_style('jefrss-reader-css', 
                plugins_url('admin/css/reader-center.css', JEFRSSFRIEND_FILE));
            
            // 新增的JS库
            wp_enqueue_script('jefrss-readability', 
                plugins_url('assets/js/readability.min.js', JEFRSSFRIEND_FILE), 
                array(), false, true);
            
            wp_enqueue_script('jefrss-marked', 
                plugins_url('assets/js/marked.min.js', JEFRSSFRIEND_FILE), 
                array(), false, true);
            
            wp_enqueue_script('jefrss-prism', 
                plugins_url('assets/js/prism.min.js', JEFRSSFRIEND_FILE), 
                array(), false, true);
            
            // Prism CSS
            wp_enqueue_style('jefrss-prism-css', 
                plugins_url('assets/css/prism.css', JEFRSSFRIEND_FILE));
            
            // 确保最后加载我们的主JS
            wp_enqueue_script('jefrss-admin', 
                plugins_url('assets/js/admin.js', JEFRSSFRIEND_FILE), 
                array('jefrss-readability', 'jefrss-marked', 'jefrss-prism'), 
                false, true);
        }
    }
    
    /**
     * 处理内容优化的AJAX请求
     */
    public function ajax_optimize_content() {
        check_ajax_referer('jefrssfriend_ajax_nonce');
        
        try {
            $article_id = isset($_POST['article_id']) ? intval($_POST['article_id']) : 0;
            
            if (!$article_id) {
                throw new Exception('无效的文章ID');
            }
            
            // 调用优化函数
            $result = jefrssfriend_optimize_content($article_id);
            
            if (!$result) {
                throw new Exception('内容优化失败');
            }
            
            wp_send_json_success(array(
                'message' => '内容优化成功',
                'content' => $result['content']
            ));
            
        } catch (Exception $e) {
            wp_send_json_error(array('message' => $e->getMessage()));
        }
    }
    
    /**
     * 处理图片优化的AJAX请求
     */
    public function ajax_process_images() {
        check_ajax_referer('jefrssfriend_ajax_nonce');
        
        try {
            $article_id = isset($_POST['article_id']) ? intval($_POST['article_id']) : 0;
            
            if (!$article_id) {
                throw new Exception('无效的文章ID');
            }
            
            $updater = new JefRSSFriend_Lite_Updater();
            $article = jefrssfriend_get_optimized_content($article_id);
            
            if (!$article) {
                throw new Exception('文章不存在');
            }
            
            // 处理图片
            $processed_content = $updater->enhance_image_processing($article->content);
            
            wp_send_json_success(array(
                'message' => '图片处理成功',
                'content' => $processed_content
            ));
            
        } catch (Exception $e) {
            wp_send_json_error(array('message' => $e->getMessage()));
        }
    }
    
    public function handle_debug_page() {
        global $wpdb;
        
        // 处理表单提交
        if (isset($_POST['action']) && $_POST['action'] === 'test_save') {
            check_admin_referer('jefrssfriend_debug_save');
            
            // 获取表单数据
            $title = wp_unslash($_POST['test_title']);
            $content = wp_unslash($_POST['test_content']);
            
            // 设置数据库编码
            $wpdb->query("SET NAMES utf8mb4");
            $wpdb->query("SET CHARACTER SET utf8mb4");
            
            // 使用原生SQL插入
            $sql = $wpdb->prepare(
                "INSERT INTO {$wpdb->prefix}jefrss_articles 
                (title, content, site_id, pub_date, link, article_hash, processed)
                VALUES (%s, %s, %d, %s, %s, %s, %d)",
                $title,
                $content,
                1, // 测试站点ID
                current_time('mysql'),
                'http://test.com',
                md5(uniqid()),
                0
            );
            
            // 执行插入
            $result = $wpdb->query($sql);
            
            if ($result !== false) {
                // 立即读取保存的内容进行验证
                $saved = $wpdb->get_row($wpdb->prepare(
                    "SELECT * FROM {$wpdb->prefix}jefrss_articles WHERE id = %d",
                    $wpdb->insert_id
                ));
                
                $save_result = array(
                    'success' => true,
                    'id' => $saved->id,
                    'content' => $saved->content,
                    'html_tags' => substr_count($saved->content, '<')
                );
                
                // 记录日志
                error_log('测试文章保存成功 - ID: ' . $saved->id);
                error_log('原始HTML标签数: ' . substr_count($content, '<'));
                error_log('保存后HTML标签数: ' . substr_count($saved->content, '<'));
            } else {
                $save_result = array(
                    'success' => false,
                    'error' => $wpdb->last_error
                );
                error_log('测试文章保存失败: ' . $wpdb->last_error);
            }
        }
        
        // 获取数据库信息
        $db_info = array(
            'charset' => $wpdb->get_var("SELECT @@character_set_database"),
            'content_charset' => $wpdb->get_var("
                SELECT CHARACTER_SET_NAME 
                FROM INFORMATION_SCHEMA.COLUMNS 
                WHERE TABLE_SCHEMA = DATABASE()
                AND TABLE_NAME = '{$wpdb->prefix}jefrss_articles'
                AND COLUMN_NAME = 'content'
            ")
        );
        
        // 显示调试页面
        include JEFRSSFRIEND_PATH . 'admin/views/debug-feed.php';
    }
    
    /**
     * 处理定时刷新任务
     */
    public function handle_cron_refresh() {
        try {
            global $wpdb;
            $sites = $wpdb->get_results("
                SELECT * FROM {$wpdb->prefix}jefrss_sites 
                WHERE status = 'active'
            ");
            
            $total_sites = count($sites);
            
            // 记录开始日志
            JefRSSFriend_Logger::log_cron(
                'start', 
                null, 
                null, 
                'success', 
                sprintf('开始定时刷新，共 %d 个源', $total_sites)
            );
            
            $processed = 0;
            $total_articles = 0;
            
            foreach ($sites as $site) {
                try {
                    $articles = $this->fetch_feed($site);
                    foreach ($articles as $article) {
                        $this->save_article($site->id, $article);
                    }
                    $total_articles += count($articles);
                    $processed++;
                } catch (Exception $e) {
                    JefRSSFriend_Logger::log_cron(
                        'error',
                        $site->id,
                        $site->site_url,
                        'error',
                        sprintf('处理失败：%s', $e->getMessage())
                    );
                }
            }

            // 在所有文章处理完成后,更新JSON缓存
            try {
                $json_result = $this->update_json_cache();
                if ($json_result) {
                    JefRSSFriend_Logger::log_cron(
                        'complete', 
                        null, 
                        null, 
                        'success', 
                        sprintf('定时刷新完成，处理 %d 个源，获取 %d 篇文章，JSON更新成功', 
                            $processed, 
                            $total_articles
                        )
                    );
                } else {
                    throw new Exception('JSON更新失败');
                }
            } catch (Exception $e) {
                JefRSSFriend_Logger::log_cron(
                    'error',
                    null,
                    null,
                    'error',
                    sprintf('JSON更新失败: %s', $e->getMessage())
                );
            }
            
        } catch (Exception $e) {
            JefRSSFriend_Logger::log_cron(
                'error',
                null,
                null,
                'error',
                sprintf('定时刷新失败: %s', $e->getMessage())
            );
        }
    }
    
    /**
     * 设置定时任务
     */
    private function setup_cron_jobs() {
        $options = get_option('jefrssfriend_options');
        
        // RSS刷新间隔
        $rss_interval = isset($options['refresh_interval']) ? 
                       intval($options['refresh_interval']) : 60;
                       
        // 清理旧的定时任务
        wp_clear_scheduled_hook('jefrssfriend_fetch_feeds');
        wp_clear_scheduled_hook('jefrssfriend_cron_refresh');
        
        // 设置新的定时任务
        if (!wp_next_scheduled('jefrssfriend_cron_refresh')) {
            wp_schedule_event(time(), 'jefrssfriend_interval', 'jefrssfriend_cron_refresh');
        }
    }
    
    /**
     * AJAX添加站点
     */
    public function ajax_add_site() {
        try {
            // 验证nonce
            check_ajax_referer('jefrssfriend-admin');
            
            // 验证权限
            if (!current_user_can('manage_options')) {
                throw new Exception('权限不足');
            }
            
            // 获取并验证数据
            $site_id = isset($_POST['site_id']) ? intval($_POST['site_id']) : 0;
            $title = isset($_POST['title']) ? sanitize_text_field($_POST['title']) : '';
            $rss_url = isset($_POST['rss_url']) ? esc_url_raw($_POST['rss_url']) : '';
            $site_url = isset($_POST['site_url']) ? esc_url_raw($_POST['site_url']) : '';
            $group_id = isset($_POST['group_id']) ? intval($_POST['group_id']) : 0;
            
            // 验证必填字段
            if (empty($title) || empty($rss_url)) {
                throw new Exception('请填写必要信息');
            }
            
            global $wpdb;
            
            // 检查RSS URL是否已存在
            $exists = $wpdb->get_var($wpdb->prepare(
                "SELECT id FROM {$wpdb->prefix}jefrss_sites 
                WHERE rss_url = %s AND id != %d",
                $rss_url,
                $site_id
            ));
            
            if ($exists) {
                throw new Exception('该RSS地址已存在');
            }
            
            $current_time = current_time('mysql');
            
            if ($site_id > 0) {
                // 更新站点
                $result = $wpdb->update(
                    $wpdb->prefix . 'jefrss_sites',
                    array(
                        'title' => $title,
                        'rss_url' => $rss_url,
                        'site_url' => $site_url,
                        'group_id' => $group_id,
                        'last_fetch' => $current_time
                    ),
                    array('id' => $site_id),
                    array('%s', '%s', '%s', '%d', '%s'),
                    array('%d')
                );
            } else {
                // 添加新站点
                $result = $wpdb->insert(
                    $wpdb->prefix . 'jefrss_sites',
                    array(
                        'title' => $title,
                        'rss_url' => $rss_url,
                        'site_url' => $site_url,
                        'group_id' => $group_id,
                        'status' => 'active',
                        'last_fetch' => $current_time
                    ),
                    array('%s', '%s', '%s', '%d', '%s', '%s')
                );
            }
            
            if ($result === false) {
                throw new Exception($wpdb->last_error);
            }
            
            // 获取新增或更新的站点ID
            $saved_site_id = $site_id > 0 ? $site_id : $wpdb->insert_id;
            
            // 立即获取一次文章
            $site = $wpdb->get_row($wpdb->prepare(
                "SELECT * FROM {$wpdb->prefix}jefrss_sites WHERE id = %d",
                $saved_site_id
            ));
            
            if ($site) {
                $refresh_result = $this->refresh_single_feed($site);
                wp_send_json_success(array(
                    'message' => '保存成功',
                    'site_id' => $saved_site_id,
                    'refresh_result' => $refresh_result
                ));
            } else {
                wp_send_json_success(array(
                    'message' => '保存成功',
                    'site_id' => $saved_site_id
                ));
            }
            
        } catch (Exception $e) {
            wp_send_json_error($e->getMessage());
        }
    }
    
    /**
     * AJAX添加分组
     */
    public function ajax_add_group() {
        try {
            check_ajax_referer('jefrssfriend-admin');
            
            $group_id = isset($_POST['group_id']) ? intval($_POST['group_id']) : 0;
            $name = isset($_POST['name']) ? sanitize_text_field($_POST['name']) : '';
            $order_num = isset($_POST['order_num']) ? intval($_POST['order_num']) : 0;
            
            if (empty($name)) {
                throw new Exception('分组名称不能为空');
            }
            
            global $wpdb;
            
            if ($group_id > 0) {
                // 更新分组 - 移除 updated_at 字段
                $result = $wpdb->update(
                    $wpdb->prefix . 'jefrss_groups',
                    array(
                        'name' => $name,
                        'order_num' => $order_num
                    ),
                    array('id' => $group_id),
                    array('%s', '%d'),
                    array('%d')
                );
            } else {
                // 添加分组 - 移除 updated_at 字段
                $result = $wpdb->insert(
                    $wpdb->prefix . 'jefrss_groups',
                    array(
                        'name' => $name,
                        'order_num' => $order_num
                    ),
                    array('%s', '%d')
                );
            }
            
            if ($result === false) {
                throw new Exception($wpdb->last_error);
            }
            
            wp_send_json_success();
            
        } catch (Exception $e) {
            wp_send_json_error($e->getMessage());
        }
    }
    
    /**
     * 删除分组的 AJAX 处理
     */
    public function ajax_delete_group() {
        try {
            check_ajax_referer('jefrssfriend-admin');
            
            $group_id = isset($_POST['id']) ? intval($_POST['id']) : 0;
            if (!$group_id) {
                throw new Exception('无效的分组ID');
            }
            
            global $wpdb;
            
            // 检查分组是否有关联的站点
            $site_count = $wpdb->get_var($wpdb->prepare(
                "SELECT COUNT(*) FROM {$wpdb->prefix}jefrss_sites WHERE group_id = %d",
                $group_id
            ));
            
            if ($site_count > 0) {
                throw new Exception('该分组下还有RSS源，不能删除');
            }
            
            // 删除分组
            $result = $wpdb->delete(
                $wpdb->prefix . 'jefrss_groups',
                array('id' => $group_id),
                array('%d')
            );
            
            if ($result === false) {
                throw new Exception('删除失败');
            }
            
            wp_send_json_success();
            
        } catch (Exception $e) {
            wp_send_json_error($e->getMessage());
        }
    }
    
    public function ajax_refresh_json() {
        check_ajax_referer('jefrssfriend-admin', 'nonce');
        
        if (!current_user_can('manage_options')) {
            wp_send_json_error('权限不足');
        }
        
        $result = $this->update_json_cache();
        if ($result) {
            wp_send_json_success('JSON缓存更新成功');
        } else {
            wp_send_json_error('JSON缓存更新失败');
        }
    }
    
    private function refresh_single_feed($site) {
        try {
            // 检查站点状态
            if ($site->status !== 'active') {
                throw new Exception('站点未激活');  // 移除第二个参数
            }
            
            // 检查RSS地址
            if (empty($site->rss_url)) {
                throw new Exception('RSS地址为空');  // 移除第二个参数
            }
            
            // 获取RSS源
            $response = wp_remote_get($site->rss_url, array(
                'timeout' => 15,
                'sslverify' => false
            ));
            
            if (is_wp_error($response)) {
                $error_code = $response->get_error_code();
                switch ($error_code) {
                    case 'http_request_failed':
                        throw new Exception('连接失败');
                    case 'timeout':
                        throw new Exception('连接超时');
                    default:
                        throw new Exception($response->get_error_message());
                }
            }
            
            $response_code = wp_remote_retrieve_response_code($response);
            if ($response_code !== 200) {
                switch ($response_code) {
                    case 403:
                        throw new Exception('访问被拒绝');
                    case 404:
                        throw new Exception('RSS源不存在');
                    default:
                        throw new Exception('HTTP错误: ' . $response_code);
                }
            }
            
            $rss = fetch_feed($site->rss_url);
            if (is_wp_error($rss)) {
                throw new Exception('RSS格式无效');  // 移除第二个参数
            }
            
            // 获取文章
            $max_items = 10;
            $rss->set_item_limit($max_items);
            $rss->init();
            $items = $rss->get_items();
            $articles_added = 0;
            
            if (!empty($items)) {
                global $wpdb;
                foreach ($items as $item) {
                    // 保存文章
                    $saved = $this->save_article($site->id, array(
                        'title' => $item->get_title(),
                        'url' => $item->get_permalink(),
                        'content' => $item->get_content(),
                        'description' => $item->get_description(),
                        'date' => $item->get_date('Y-m-d H:i:s')
                    ));
                    
                    if ($saved) {
                        $articles_added++;
                    }
                }
                
                // 更新最后抓取时间
                $wpdb->update(
                    $wpdb->prefix . 'jefrss_sites',
                    array('last_fetch' => current_time('mysql')),
                    array('id' => $site->id)
                );
                
                // 更新 JSON 缓存
                $this->update_json_cache();
                
                return array(
                    'success' => true,
                    'articles_count' => $articles_added
                );
            }
            
            return array(
                'success' => true,
                'articles_count' => 0
            );
            
        } catch (Exception $e) {
            error_log('刷新站点失败: ' . $e->getMessage());
            return array(
                'success' => false,
                'error_type' => $e->getCode(),
                'message' => $e->getMessage()
            );
        }
    }
    
    /**
     * AJAX激活所有站点
     */
    public function ajax_activate_all_sites() {
        check_ajax_referer('jefrssfriend-admin');
        
        if (!current_user_can('manage_options')) {
            wp_send_json_error('权限不足');
        }
        
        global $wpdb;
        
        try {
            $result = $wpdb->query("
                UPDATE {$wpdb->prefix}jefrss_sites 
                SET status = 'active' 
                WHERE status != 'active' OR status IS NULL
            ");
            
            if ($result !== false) {
                wp_send_json_success(array(
                    'message' => '所有站点已激活',
                    'updated' => $result
                ));
            } else {
                throw new Exception($wpdb->last_error);
            }
            
        } catch (Exception $e) {
            wp_send_json_error('激活站点失败: ' . $e->getMessage());
        }
    }
    
    public function ajax_get_article() {
        try {
            check_ajax_referer('jefrssfriend-admin');
            
            $article_id = isset($_POST['id']) ? intval($_POST['id']) : 0;
            if (!$article_id) {
                throw new Exception('无效的文章ID');
            }
            
            global $wpdb;
            $article = $wpdb->get_row($wpdb->prepare("
                SELECT a.*, s.title as site_title, s.site_url, s.icon_url
                FROM {$wpdb->prefix}jefrss_articles a
                LEFT JOIN {$wpdb->prefix}jefrss_sites s ON a.site_id = s.id
                WHERE a.id = %d
            ", $article_id));
            
            if (!$article) {
                throw new Exception('文章不存在');
            }
            
            ob_start();
            ?>
            <div class="article-container">
                <h1>
                    <a href="<?php echo esc_url($article->link); ?>" target="_blank">
                        <?php echo esc_html($article->title); ?>
                    </a>
                </h1>
                <div class="jef-meta-info">
                    <div class="site-info">
                        <img src="<?php echo esc_url(jefrssfriend_get_site_icon($article)); ?>" 
                             class="site-icon" 
                             alt="<?php echo esc_attr($article->site_title); ?>">
                        <span class="site-title"><?php echo esc_html($article->site_title); ?></span>
                    </div>
                    
                    <time><?php echo human_time_diff(strtotime($article->pub_date)) . __('前', 'jefrssfriend'); ?></time>
                    
                    <button class="toggle-dark-mode" title="<?php _e('切换夜间模式', 'jefrssfriend'); ?>">
                        <svg viewBox="0 0 24 24" width="18" height="18">
                            <path d="M12 3a9 9 0 1 0 9 9c0-.46-.04-.92-.1-1.36a5.389 5.389 0 0 1-4.4 2.26 5.403 5.403 0 0 1-3.14-9.8c-.44-.06-.9-.1-1.36-.1z"/>
                        </svg>
                    </button>
                    
                    <div class="jef-font-control">
                        <button data-size="small" class="jef-size-btn">小</button>
                        <button data-size="medium" class="jef-size-btn active">中</button>
                        <button data-size="large" class="jef-size-btn">大</button>
                    </div>
                </div>
                <div class="jef-article-content">
                    <?php echo wp_kses_post($article->content); ?>
                </div>
                <div class="article-footer">
                    <a href="<?php echo esc_url($article->link); ?>" 
                       class="original-link" 
                       target="_blank">
                        <?php _e('访问原文', 'jefrssfriend'); ?> →
                    </a>
                </div>
            </div>
            <?php
            $content = ob_get_clean();
            
            wp_send_json_success(array(
                'content' => $content
            ));
            
        } catch (Exception $e) {
            wp_send_json_error($e->getMessage());
        }
    }
    
    /**
     * 刷新单个站点的 AJAX 处理
     */
    public function ajax_refresh_single_site() {
        try {
            check_ajax_referer('jefrssfriend-admin');
            
            $site_id = isset($_POST['id']) ? intval($_POST['id']) : 0;
            if (!$site_id) {
                throw new Exception('无效的站点ID');
            }
            
            global $wpdb;
            
            // 获取站点信息
            $site = $wpdb->get_row($wpdb->prepare(
                "SELECT * FROM {$wpdb->prefix}jefrss_sites WHERE id = %d",
                $site_id
            ));
            
            if (!$site) {
                throw new Exception('站点不存在');
            }
            
            // 添加开始日志
            JefRSSFriend_Logger::log_manual('start', $site->id, $site->site_url, 'success', 
                "开始刷新站点: {$site->title}");
            
            $result = $this->refresh_single_feed($site);
            
            if (isset($result['success']) && !$result['success']) {
                // 添加错误日志
                JefRSSFriend_Logger::log_manual('error', $site->id, $site->site_url, 'error', 
                    $result['message'] ?? '刷新失败');
                wp_send_json_error($result);
            } else {
                // 添加成功日志
                JefRSSFriend_Logger::log_manual('complete', $site->id, $site->site_url, 'success', 
                    sprintf('成功刷新，获取%d篇文章', $result['articles_count'] ?? 0));
                wp_send_json_success(array(
                    'message' => '刷新成功',
                    'articles_count' => $result['articles_count'] ?? 0,
                    'last_fetch' => current_time('mysql')
                ));
            }
            
        } catch (Exception $e) {
            // 添加异常日志
            if (isset($site)) {
                JefRSSFriend_Logger::log_manual('error', $site->id, $site->site_url, 'error', 
                    $e->getMessage());
            } else {
                JefRSSFriend_Logger::log_manual('error', null, null, 'error', 
                    $e->getMessage());
            }
            wp_send_json_error(array(
                'error_type' => $e->getCode(),
                'message' => $e->getMessage()
            ));
        }
    }

    public function render_logs_page() {
        // 获取筛选参数
        $status = isset($_GET['status']) ? sanitize_text_field($_GET['status']) : '';
        
        // 分页参数
        $paged = isset($_GET['paged']) ? max(1, intval($_GET['paged'])) : 1;
        $per_page = 20;
        $offset = ($paged - 1) * $per_page;
        
        // 构建查询
        global $wpdb;
        $where = array();
        $where_values = array();
        
        // 只添加状态筛选条件
        if ($status) {
            $where[] = "status = %s";
            $where_values[] = $status;
        }
        
        // 构建 WHERE 子句
        $where_sql = !empty($where) ? 
            "WHERE " . implode(" AND ", $where) : "";
        
        // 如果有条件，准备SQL语句
        if (!empty($where_values)) {
            $query = $wpdb->prepare(
                "SELECT * FROM {$wpdb->prefix}jefrss_logs 
                {$where_sql}
                ORDER BY created_at DESC 
                LIMIT %d OFFSET %d",
                array_merge($where_values, array($per_page, $offset))
            );
        } else {
            // 没有筛选条件的情况
            $query = $wpdb->prepare(
                "SELECT * FROM {$wpdb->prefix}jefrss_logs 
                ORDER BY created_at DESC 
                LIMIT %d OFFSET %d",
                $per_page, $offset
            );
        }
        
        // 获取日志数据
        $logs = $wpdb->get_results($query);
        
        // 加载视图
        include JEFRSSFRIEND_PATH . 'admin/views/logs-page.php';
    }

    // 添加辅助函数
    private function get_type_label($type) {
        $labels = array(
            'cron' => __('定时抓取', 'jefrssfriend'),
            'manual' => __('手动刷新', 'jefrssfriend')
        );
        return isset($labels[$type]) ? $labels[$type] : $type;
    }

    private function get_action_label($action) {
        $labels = array(
            'start' => __('开始', 'jefrssfriend'),
            'complete' => __('完成', 'jefrssfriend'),
            'error' => __('错误', 'jefrssfriend')
        );
        return isset($labels[$action]) ? $labels[$action] : $action;
    }

    private function get_status_label($status) {
        $labels = array(
            'success' => __('成功', 'jefrssfriend'),
            'error' => __('失败', 'jefrssfriend')
        );
        return isset($labels[$status]) ? $labels[$status] : $status;
    }

    private function get_pagination_links() {
        global $wpdb;
        
        // 获取当前页码
        $paged = isset($_GET['paged']) ? max(1, intval($_GET['paged'])) : 1;
        $per_page = 20; // 每页显示数量
        
        // 构建WHERE子句
        $where = array();
        if (!empty($_GET['log_type'])) {
            $where[] = $wpdb->prepare("type = %s", sanitize_text_field($_GET['log_type']));
        }
        if (!empty($_GET['status'])) {
            $where[] = $wpdb->prepare("status = %s", sanitize_text_field($_GET['status']));
        }
        $where_sql = !empty($where) ? "WHERE " . implode(" AND ", $where) : "";
        
        // 获取总记录数
        $total_items = $wpdb->get_var("
            SELECT COUNT(*) 
            FROM {$wpdb->prefix}jefrss_logs 
            {$where_sql}
        ");
        
        // 计算总页数
        $total_pages = ceil($total_items / $per_page);
        
        // 构建分页链接
        $page_links = paginate_links(array(
            'base' => add_query_arg('paged', '%#%'),
            'format' => '',
            'prev_text' => __('&laquo;'),
            'next_text' => __('&raquo;'),
            'total' => $total_pages,
            'current' => $paged,
            'type' => 'array'
        ));
        
        if ($page_links) {
            return '<div class="tablenav-pages">' . 
                   '<span class="displaying-num">' . 
                   sprintf(_n('%s 项', '%s 项', $total_items), number_format_i18n($total_items)) . 
                   '</span>' .
                   '<span class="pagination-links">' . 
                   implode("\n", $page_links) . 
                   '</span>' .
                   '</div>';
        }
        
        return '';
    }

    public function render_mobile_reader_view() {
        // 直接加载移动端视图文件，不需要加载PC端视图
        require_once JEFRSSFRIEND_PATH . 'admin/views/reader-center-mobile.php';
        $reader = new JefRSSFriend_Mobile_Reader_View();
        $reader->render();
    }

    public function render_reader_view() {
        require_once JEFRSSFRIEND_PATH . 'admin/views/reader-center.php';
        $reader = new JefRSSFriend_Reader_View();
        $reader->render();
    }

    public function handle_ajax_requests() {
        // 验证 nonce
        check_ajax_referer('jefrssfriend-admin', 'nonce');
        
        if (!current_user_can('read')) {
            wp_send_json_error('权限不足');
            return;
        }

        $action = $_POST['action'] ?? '';
        
        switch ($action) {
            case 'jefrssfriend_get_article':
                $this->get_article_content();
                break;
            case 'jefrssfriend_refresh_articles':
                $this->refresh_articles();
                break;
            case 'jefrssfriend_save_reading_state':
                $this->save_reading_state();
                break;
            default:
                wp_send_json_error('未知操作');
                break;
        }
    }

    protected function get_article_content() {
        $article_id = isset($_POST['id']) ? intval($_POST['id']) : 0;
        if (!$article_id) {
            wp_send_json_error('无效的文章ID');
            return;
        }
        
        global $wpdb;
        $article = $wpdb->get_row($wpdb->prepare("
            SELECT a.*, s.title as site_title, s.site_url
            FROM {$wpdb->prefix}jefrss_articles a
            LEFT JOIN {$wpdb->prefix}jefrss_sites s ON a.site_id = s.id
            WHERE a.id = %d
        ", $article_id));
        
        if (!$article) {
            wp_send_json_error('文章不存在');
            return;
        }
        
        ob_start();
        ?>
        <div class="article-container">
            <h1>
                <a href="<?php echo esc_url($article->link); ?>" target="_blank">
                    <?php echo esc_html($article->title); ?>
                </a>
            </h1>
            <div class="article-meta">
                <span class="site-info">
                    <img src="<?php echo esc_url($this->get_site_icon($article)); ?>" 
                         class="site-icon" 
                         alt="<?php echo esc_attr($article->site_title); ?>">
                    <span class="site-title"><?php echo esc_html($article->site_title); ?></span>
                </span>
                <time><?php echo human_time_diff(strtotime($article->pub_date)) . __('前', 'jefrssfriend'); ?></time>
            </div>
            <div class="article-content">
                <?php echo wp_kses_post($article->content); ?>
            </div>
            <div class="article-footer">
                <a href="<?php echo esc_url($article->link); ?>" class="original-link" target="_blank">
                    <?php _e('访问原文', 'jefrssfriend'); ?> →
                </a>
            </div>
        </div>
        <?php
        $content = ob_get_clean();
        
        wp_send_json_success(array(
            'content' => $content
        ));
    }

    public function ajax_get_articles() {
        check_ajax_referer('jefrssfriend-admin');
        
        $page = isset($_POST['page']) ? intval($_POST['page']) : 1;
        $per_page = 50;
        $offset = ($page - 1) * $per_page;
        
        global $wpdb;
        $articles = $wpdb->get_results($wpdb->prepare("
            SELECT a.*, s.title as site_title, s.site_url 
            FROM {$wpdb->prefix}jefrss_articles a
            LEFT JOIN {$wpdb->prefix}jefrss_sites s ON a.site_id = s.id
            WHERE s.status = 'active'
            ORDER BY a.pub_date DESC 
            LIMIT %d OFFSET %d
        ", $per_page, $offset));
        
        wp_send_json_success([
            'articles' => $articles,
            'hasMore' => count($articles) === $per_page
        ]);
    }

    public function enqueue_scripts() {
        // ... 其他代码

        // 添加 darkmode-js 依赖
        wp_enqueue_script(
            'darkmode-js',
            'https://cdn.jsdelivr.net/npm/darkmode-js@1.5.7/lib/darkmode-js.min.js',
            array(),
            '1.5.7',
            true
        );

        // 确保 mobile-reader.js 依赖 darkmode-js
        wp_enqueue_script(
            'jefrssfriend-mobile-reader',
            plugin_dir_url(__FILE__) . '../assets/js/mobile-reader.js',
            array('jquery', 'darkmode-js'),
            $this->version,
            true
        );
    }

    public function handle_fix_times() {
        if (isset($_POST['action']) && $_POST['action'] === 'fix_log_times') {
            check_admin_referer('fix_log_times', 'fix_times_nonce');
            
            if (!current_user_can('manage_options')) {
                wp_die('权限不足');
            }
            
            $fixed = JefRSSFriend_Logger::fix_log_times();
            
            add_settings_error(
                'jefrssfriend_messages',
                'times_fixed',
                sprintf('已修复 %d 条时间记录', $fixed),
                'updated'
            );
            
            wp_redirect(add_query_arg(array(
                'page' => 'jefrssfriend-logs',
                'fixed' => $fixed
            ), admin_url('admin.php')));
            exit;
        }
    }
} 