<?php
/*
Plugin Name: Jefrss Reader Lite
Plugin URI: https://www.jeffer.xyz/jefrss-reader-lite
Description: 一个轻量级的WordPress RSS阅读器插件。支持OPML导入导出、文章内容优化、多语言支持、移动端阅读等功能。适合个人博客订阅文章更新，支持分组管理和定时抓取。
Version: 1.0.0
Author: Jeffer.Z
Author URI: https://www.jeffer.xyz
License: GPL v2 or later
Text Domain: jefrssfriend
Domain Path: /languages

JefRSS Reader Lite is a lightweight RSS reader plugin for WordPress.
Copyright (C) 2024 Jeffer.Z

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 2 of the License, or
any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
*/


if (!defined('ABSPATH')) exit;

// 只在需要调试时设置为 true
define('JEFRSSFRIEND_DEBUG', false);

// 定义插件常量
if (!defined('JEFRSSFRIEND_VERSION')) {
    define('JEFRSSFRIEND_VERSION', '1.0.0');
}
if (!defined('JEFRSSFRIEND_FILE')) {
    define('JEFRSSFRIEND_FILE', __FILE__);
}
if (!defined('JEFRSSFRIEND_PATH')) {
    define('JEFRSSFRIEND_PATH', plugin_dir_path(__FILE__));
}
if (!defined('JEFRSSFRIEND_URL')) {
    define('JEFRSSFRIEND_URL', plugin_dir_url(__FILE__));
}

// 引入必要的文件
require_once JEFRSSFRIEND_PATH . 'includes/class-jefrssfriend.php';
require_once JEFRSSFRIEND_PATH . 'includes/class-jefrssfriend-activator.php';
require_once JEFRSSFRIEND_PATH . 'includes/class-jefrssfriend-updater.php';
require_once JEFRSSFRIEND_PATH . 'includes/class-jefrssfriend-settings.php';
require_once JEFRSSFRIEND_PATH . 'includes/class-jefrssfriend-admin.php';
require_once JEFRSSFRIEND_PATH . 'includes/helpers.php';
require_once JEFRSSFRIEND_PATH . 'includes/class-jefrssfriend-logger.php';

// 激活插件时创建数据表
function jefrss_reader_lite_activate() {
    if (JEFRSSFRIEND_DEBUG) {
        error_log('JefRSS: Starting plugin activation...');
    }
    
    // 修改这里，使用Activator类
    JefRSSFriend_Activator::activate();
    
    // 添加JSON更新标记选项
    add_option('jefrssfriend_need_json_update', false);
}
register_activation_hook(__FILE__, 'jefrss_reader_lite_activate');

// 停用插件时清理
function jefrss_reader_lite_deactivate() {
    $plugin = new JefRSSFriend_Lite_Core();
    $plugin->deactivate();
}
register_deactivation_hook(__FILE__, 'jefrss_reader_lite_deactivate');

// 在插件停用时清理定时任务
register_deactivation_hook(__FILE__, function() {
    wp_clear_scheduled_hook('jefrssfriend_cron_refresh');
});

// 卸载插件时清理
function jefrss_reader_lite_uninstall() {
    $plugin = new JefRSSFriend_Lite_Core();
    $plugin->uninstall();
}
register_uninstall_hook(__FILE__, 'jefrss_reader_lite_uninstall');

// 初始化插件
function jefrss_reader_lite_init() {
    $plugin = new JefRSSFriend_Lite_Core();
    $plugin->init();
}
add_action('plugins_loaded', 'jefrss_reader_lite_init'); 


/**
 * 添加插件设置链接
 * 
 * @param array $links 现有的插件操作链接
 * @return array 修改后的链接数组
 */
function jefrssfriend_plugin_action_links($links) {
    // 添加设置链接
    $settings_link = '<a href="' . admin_url('admin.php?page=jefrssfriend-settings') . '">' . 
                     __('设置', 'jefrssfriend') . '</a>';
    
    // 将设置链接添加到数组开头
    array_unshift($links, $settings_link);
    
    return $links;
}

// 添加插件操作链接过滤器
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'jefrssfriend_plugin_action_links'); 